@@ -1,6 +1,6 @@
 from .runner import run, sh
 
 __all__ = [
-    run,
-    sh,
+    'run',
+    'sh',
 ]
