@@ -54,11 +54,9 @@ def represent_file(file: Union[str, io.IOBase]):
 
 
 class ShalchemyExpression:
-    @property
     def read_sub(self) -> 'ReadSubstitute':
         return ReadSubstitute(self)
 
-    @property
     def write_sub(self) -> 'WriteSubstitute':
         return WriteSubstitute(self)
 
@@ -100,13 +98,16 @@ class ShalchemyExpression:
     def __int__(self):
         return int(str(self))
 
-    def __str__(self):
+    def __bytes__(self):
         from .runner import _internal_run
         result = _internal_run(self, stdout=subprocess.PIPE)
-        answer = result.main.stdout.read().decode()
+        answer = result.main.stdout.read()
         result.wait()
         return answer
 
+    def __str__(self):
+        return bytes(self).decode()
+
     def __iter__(self):
         return str(self).rstrip('\n').split('\n').__iter__()
 
@@ -296,7 +297,7 @@ class RedirectInExpression(ShalchemyExpression):
 
     def _make_os_file(self, file: ShalchemyFile) -> FileResult:
         if isinstance(file, str):
-            osfile = cast(io.IOBase, open(file, 'r'))
+            osfile = cast(io.IOBase, open(file, 'rb'))
             return FileResult(fileno=osfile.fileno(), open_files=[osfile])
 
         try:
@@ -367,7 +368,7 @@ class RedirectOutExpression(ShalchemyExpression):
                 return FileResult(fileno=subprocess.STDOUT, open_files=[])
             elif file == '&2':
                 raise ValueError('Redirects to stderr (&2) is unsupported')
-            mode = 'a' if append else 'w'
+            mode = 'ab' if append else 'wb'
             osfile = open(file, mode)
             return FileResult(fileno=osfile.fileno(), open_files=[cast(io.IOBase, osfile)])
 
@@ -470,7 +471,7 @@ class ReadSubstitute(ProcessSubstituteExpression):
             is called Process Substitution.
 
             The way you do the same with shalchemy is:
-            diff('file.txt', curl('example.com/file.txt').read_sub)
+            diff('file.txt', curl('example.com/file.txt').read_sub())
 
             Once an expression's `read_sub` method is called, the result is a
             ProcessSubstituteExpression which can no longer be composed with
